def print_lol(the_list, level):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for tab in range(level):
                print("\t", end='')
            print(each_item)

"""
movies = ["The Holy Grail", 1975, "Terry Jones & Terry Gilliam", 91, 
                ["Graham Chapman", ["Michael Palin", "John Cleese",
                        "Terry Gilliam", "Eric Idle", "Terry Jones"]]]

print_lol(movies, 0)
"""



from distutils.core import setup

setup(
        name            = 'djnester',
        version         = '1.1.0',
        py_modules      = ['nester'],
        author          = 'danjiang',
        author_email    = 'danjiang5956@gmail.com',
        url             = 'http://danthought.com',
        description     = 'A simple printer of nested lists',
    )
